<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="km_KH">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="obsolete">លុប</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="obsolete">ពេញ​អេក្រង់</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="obsolete">បញ្ចាំងស្លាយ</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="obsolete">នាំចេញ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="obsolete">ចម្លង</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="obsolete">ចំណូលចិត្ត</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">បង្វិលតាមទ្រនិចនាឡិកា</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="obsolete">បង្វិលច្រាសទ្រនិចនាឡិកា</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="obsolete">កំណត់ជាផ្ទាំងរូបភាព</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="obsolete">បង្ហាញនៅក្នុងកម្មវិធីគ្រប់គ្រងឯកសារ</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="obsolete">ព័ត៌មានរូបថត</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="obsolete">ស្តារ</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>គ្មានឈ្មោះ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>បោះបង់</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>បង្កើត</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>អាល់ប៊ុមថ្មី</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>បោះបង់</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>លុប</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>តើអ្នកពិតជាចង់លុបអាល់ប៊ុមនេះមែនទេ?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>សំរាម</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>ចំណូលចិត្ត</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>នាំចូល</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>សំរាម</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>ចំណូលចិត្ត</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>ឬអូសរូបថតនៅទីនេះ</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>នាំចូលទាំងអស់</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>នាំចូលទៅ៖</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>នាំចូល</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>ថាសប្រព័ន្ធ</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>វិចិត្រសាល</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>ថាសរវល់មិនអាចច្រានចេញបានទេឥឡូវនេះ</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>យល់ព្រម</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>អាល់ប៊ុមថ្មី</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>បោះបង់</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>មិនអើពើ</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>អាល់ប៊ុម</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>បោះបង់</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>ជំនួស</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>នាំចេញ</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>រូបភាព</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>ឯកសារ</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>ទាញយក</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>ផ្ទៃតុ</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>វីដេអូ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>តន្ត្រី</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>ឈ្មោះ៖</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>រក្សាទុកនៅ៖</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>ទ្រង់ទ្រាយ៖</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>គុណភាព៖</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>រក្សាទុក</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>ជ្រើសរើសថតផ្សេងទៀត</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>យល់ព្រម</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>ឈ្មោះឯកសារមិនអាចទទេបានទេ</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>ធ្លាប់​មាន​រួចហើយ។ តើអ្នកចង់ជំនួសវាទេ?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 ថាស</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>%1 ថាសទទេ</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 បានអ៊ិនគ្រីប</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 ចំនួន</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>រក្សាទុក</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>នាំចេញរូបថត</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>បោះបង់</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>កំពុងលុប...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>កំពុងស្ដារ...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>បោះបង់</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>លុប</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>ព័ត៌មានបឋម</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>ព័ត៌មានលម្អិត</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>នាំចូល</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>បញ្ចាំងស្លាយ</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>ប្តូរឈ្មោះ</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>នាំចេញ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>លុប</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>ឧបករណ៍</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>វិចិត្រសាល</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>អាល់ប៊ុម</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>អាល់ប៊ុមថ្មី</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>រូបថត</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>ពេញ​អេក្រង់</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ជំនួយ</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>បង្ហាញនៅក្នុងកម្មវិធីគ្រប់គ្រងឯកសារ</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>បញ្ចាំងស្លាយ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>ចម្លង</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>កំណត់ជាផ្ទាំងរូបភាព</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>បង្វិលតាមទ្រនិចនាឡិកា</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>បង្វិលច្រាសទ្រនិចនាឡិកា</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>មុន</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>បន្ទាប់</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ចំណូលចិត្ត</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>មិនចូលចិត្ត</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>ប្តូរឈ្មោះអាល់ប៊ុម</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>អាល់ប៊ុម “%1” បានយកចេញ</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>បន្ថែមដោយជោគជ័យទៅក្នុង “%1”</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>នាំចូលបានជោគជ័យ</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>នាំចូលបានបរាជ័យ</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>នាំចេញបានបរាជ័យ</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>នាំចេញបានជោគជ័យ</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>រូបថតទាំងអស់</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>ពេលវេលា</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>អាល់ប៊ុម</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>ចេញពីអេក្រង់ពេញ / បញ្ចាំងស្លាយ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>បង្ហាញផ្លូវកាត់</translation>
    </message>
    <message>
        <source>View</source>
        <translation>មើល</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>ជ្រើស​យក​ទាំងអស់</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>ពង្រីក</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>បង្រួម</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>អាល់ប៊ុមថ្មី</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>ទំព័រឡើងលើ</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>ទំព័រចុះក្រោម</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>ការកំណត់</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>កំពុងនាំចូល...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">លុប</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>ពន្លឺ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>ប្រភេទ</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>ទំហំឯកសារ</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>វិមាត្រ</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>កាលបរិច្ឆេទចាប់យក</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>កាលបរិច្ឆេទបានកែប្រែ</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>របៀបបង្ហាញ</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>កម្មវិធីបង្ហាញ</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>រយៈពេល​បង្ហាញ</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>ជំរៅ</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>ប្រវែងប្រសព្វ</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>ជំរៅអតិបរមា</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>ម៉ូតម៉ែត្រ</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>តុល្យភាពពណ៌ស</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>សំណងពន្លឺ</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>ម៉ូដែលម៉ាស៊ីនថត</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>ម៉ូដែលកែវ</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>ចន្លោះពណ៌</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>ស្លាក</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>ថាសប្រព័ន្ធ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>ជ្រើសរើស</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>មិនជ្រើសរើស</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>បាននាំចូលលើ</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>បាននាំចូលលើ</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>បោះបង់</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>ស្តារ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>លុប</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>រូបថត</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>វីដេអូ</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ចំណូលចិត្ត</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>បង្វិលច្រាសទ្រនិចនាឡិកា</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>បង្វិលតាមទ្រនិចនាឡិកា</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>កំពុងនាំចូល...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>គ្មានលទ្ធផលស្វែងរកទេ</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>បញ្ចាំងស្លាយ</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>លទ្ធផលស្វែងរក</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>មើល</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>ពេញ​អេក្រង់</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>នាំចេញ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ចំណូលចិត្ត</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>មិនចូលចិត្ត</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>បង្វិលតាមទ្រនិចនាឡិកា</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>បង្វិលច្រាសទ្រនិចនាឡិកា</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>បង្ហាញនៅក្នុងកម្មវិធីគ្រប់គ្រងឯកសារ</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>កំណត់ជាផ្ទាំងរូបភាព</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>លុប</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>បញ្ចាំងស្លាយ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>ចម្លង</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>ព័ត៌មានរូបថត</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>បន្ថែមទៅអាល់ប៊ុម</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>យកចេញពីអាល់ប៊ុម</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>ស្តារ</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>អាល់ប៊ុមថ្មី</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>បោះពុម្ព</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">ថ្ងៃ</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">ព័ត៌មានបឋម</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">កាលបរិច្ឆេទបានកែប្រែ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">ប្រភេទ</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">ទំហំឯកសារ</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">កាលបរិច្ឆេទចាប់យក</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
